@@ -136,6 +136,8 @@ def _fill(db, fill_with, to_fill, attr):
 
     import nfldb.query
     ids = list(set(pkval(obj) for obj in to_fill))
+    if len(ids) == 0:
+        return
     objs = nfldb.query._entities_by_ids(db, fill_with, *ids)
     byid = dict([(pkval(obj), obj) for obj in objs])
     for obj in to_fill:
@@ -1411,7 +1413,8 @@ class SQLPlay (sql.Entity):
                       ] + _play_categories.keys()),
             ('agg_play', _player_categories.keys()),
         ],
-        'derived': ['offense_yds', 'offense_tds', 'defense_tds', 'points'],
+        'derived': ['offense_yds', 'offense_tds', 'defense_tds', 'points',
+                    'game_date'],
     }
 
     @classmethod
@@ -1424,6 +1427,9 @@ class SQLPlay (sql.Entity):
             fields = ['(%s * %d)' % (cls._sql_field(f, aliases=aliases), pval)
                       for f, pval in PlayPlayer._point_values]
             return 'GREATEST(%s)' % ', '.join(fields)
+        elif name == 'game_date':
+            gsis_id = cls._sql_field('gsis_id', aliases=aliases)
+            return 'SUBSTRING(%s from 1 for 8)' % gsis_id
         else:
             return super(SQLPlay, cls)._sql_field(name, aliases=aliases)
 
@@ -1742,12 +1748,6 @@ class Play (SQLPlay):
     def __getattr__(self, k):
         if k in Play.__slots__:
             return 0
-        if k in PlayPlayer.__slots__:
-            for pp in self.play_players:
-                v = getattr(pp, k)
-                if v != 0:
-                    return v
-            return 0
         raise AttributeError(k)
 
 
@@ -1820,6 +1820,7 @@ class Drive (SQLDrive):
                 play.time = _play_time(dbd, play, next)
             if play.time is not None:
                 dbd._plays.append(play)
+        dbd._plays.sort(key=lambda p: p.play_id)
         return dbd
 
     @staticmethod
@@ -2104,6 +2105,7 @@ class Game (SQLGame):
             if not hasattr(drive, 'game'):
                 continue
             dbg._drives.append(Drive._from_nflgame(db, dbg, drive))
+        dbg._drives.sort(key=lambda d: d.drive_id)
         return dbg
 
     @staticmethod
